@@ -27,14 +27,6 @@ class ZodiacalFrg(Logger):
     radiance: Radiance
         zodiacal radiance
 
-    Methods
-    --------
-    model(A)
-        returns the zodiacal Radiance for the zodiacal light model presented in Glasse et al. 2010,
-        scaled by coefficient fitted over Kelsall et al. 1998 model
-    zodiacal_fit_direction(coord)
-        returns the fitted coefficient for the zodiacal model given the target position.
-        It's based on Kelsall et al. 1998 model
     """
 
     def __init__(self, wl, description, coordinates=None):
@@ -44,13 +36,17 @@ class ZodiacalFrg(Logger):
         self.radiance = self._get_radiance(coordinates)
 
     def _get_radiance(self, coordinates):
-        if coordinates and 'zodiacalMap' in self.description:
-            if 'zodiacalMap':
-                try:
-                    A = self.zodiacal_fit_direction(coordinates)
-                except (KeyError, OSError):
-                    self.warning('zodiacal fit failed')
-                    self._get_radiance(coordinates=None)
+
+        fit_coord = self.description['zodiacalMap'][
+            'value'] if 'zodiacalMap' in self.description else False
+        map_file = self.description['custom_map_file'][
+            'value'] if 'custom_map_file' in self.description else None
+        if fit_coord and coordinates:
+            try:
+                A = self.zodiacal_fit_direction(coordinates, map_file)
+            except (KeyError, OSError):
+                self.warning('zodiacal fit failed')
+                self._get_radiance(coordinates=None)
 
         elif 'zodiacFactor' in self.description:
             self.debug(' model used for zodiacal foreground')
@@ -63,31 +59,45 @@ class ZodiacalFrg(Logger):
         return self.model(A)
 
     def model(self, A):
+        """
+        returns the zodiacal Radiance for the zodiacal light model presented in Glasse et al. 2010,
+        scaled by coefficient fitted over Kelsall et al. 1998 model
+        """
         units = u.W / (u.m ** 2 * u.um * u.sr)
         zodi_emission = A * (3.5e-14 * planck(self.wl, 5500.0 * u.K) +
                              3.58e-8 * planck(self.wl, 270.0 * u.K)).to(units)
         return Radiance(self.wl, zodi_emission)
 
-    def zodiacal_fit_direction(self, coord):
+    def zodiacal_fit_direction(self, coord, map_file=None):
+        """
+        returns the fitted coefficient for the zodiacal model given the target position.
+        It's based on Kelsall et al. 1998 model
+        """
         import os
-        from pathlib import Path
         from astropy.io.misc.hdf5 import read_table_hdf5
         import numpy as np
+        from pathlib import Path
 
         ra_input = coord[0]
         dec_input = coord[1]
 
-        dir_path = Path(os.path.dirname(os.path.realpath(__file__)))
-        i = 0
-        while 'data' not in [d.stem for d in Path(dir_path).iterdir() if d.is_dir()] or i > 10:
-            dir_path = dir_path.parent
-            i += 1
-        if i > 10:
-            self.error('Zodi map file not found')
-            raise OSError('Zodi map file not found')
+        exorad_path = Path(__file__).parent.parent.parent.absolute()
+        zodi_map_file = map_file if map_file else os.path.join(exorad_path, 'data/Zodi_map.hdf5')
+
+        if not os.path.isfile(zodi_map_file):
+            dir_path = Path(__file__).parent.absolute()
+
+            i = 0
+            while 'data' not in [d.stem for d in Path(dir_path).iterdir() if d.is_dir()] and i < 10:
+                dir_path = dir_path.parent
+                i += 1
+            if i > 10:
+                self.error('Zodi map file not found')
+                raise OSError('Zodi map file not found')
+
+            data_path = os.path.join(dir_path.absolute().as_posix(), 'data')
+            zodi_map_file = os.path.join(data_path, 'Zodi_map.hdf5')
 
-        data_path = os.path.join(dir_path.absolute().as_posix(), 'data')
-        zodi_map_file = os.path.join(data_path, 'Zodi_map.hdf5')
         self.debug('map data:{}'.format(zodi_map_file))
 
         try:
